@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2020 Free Software Foundation, Inc.
+   Copyright (C) 2009-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -169,6 +169,16 @@ enum mu_buffer_type
      Arg: struct mu_locus_range *
   */
 #define MU_IOCTL_LOGSTREAM_SET_LOCUS_RANGE   16
+
+  /* Get prefix.
+     Arg: char **
+  */
+#define MU_IOCTL_LOGSTREAM_GET_PREFIX        17
+
+  /* Set prefix.
+     Arg: char *
+  */
+#define MU_IOCTL_LOGSTREAM_SET_PREFIX        18  
   
   /* Opcodes for MU_IOCTL_XSCRIPTSTREAM */
   /* Swap transcript levels.
@@ -361,8 +371,16 @@ int mu_stream_printf (mu_stream_t stream, const char *fmt, ...)
 
 int mu_stream_copy (mu_stream_t dst, mu_stream_t src, mu_off_t size,
 		    mu_off_t *pcsz);
+int mu_stream_copy_wcb (mu_stream_t dst, mu_stream_t src, mu_off_t size,
+			void (*cbf) (char *, size_t, void *), void *cbd,
+			mu_off_t *pcsz);
+int mu_stream_copy_nl (mu_stream_t dst, mu_stream_t src, mu_off_t size,
+		       mu_off_t *pcsz);
+
 int mu_stream_header_copy (mu_stream_t dst, mu_stream_t src, char **exclude_names);
 
+int mu_stream_shift (mu_stream_t str, mu_off_t off_a, mu_off_t off_b,
+		     size_t bufsize);
 
 int mu_file_stream_create (mu_stream_t *pstream, const char *filename, int flags);
 struct mu_tempfile_hints;  
@@ -456,7 +474,10 @@ int mu_nullstream_create (mu_stream_t *pref, int flags);
 
 int mu_wordwrap_stream_create (mu_stream_t *pstream, mu_stream_t transport,
 			       size_t left_margin, size_t right_margin);
-  
+
+extern size_t mu_temp_file_threshold_size;
+int mu_temp_stream_create (mu_stream_t *pstream, size_t threshold);
+
 #ifdef __cplusplus
 }
 #endif
