@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2007-2020 Free Software Foundation, Inc.
+   Copyright (C) 2007-2021 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,15 +18,6 @@
 
 int exit_code;
 
-void
-mda_close_fds (void)
-{
-  int i;
-  long fdlimit = sysconf (_SC_OPEN_MAX);
-  for (i = 3; i < fdlimit; i++)
-    close (i);
-}
-
 int
 mda_switch_user_id (struct mu_auth_data *auth, int user)
 {
