@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2012, 2014-2017 Free Software Foundation, Inc.
+   Copyright (C) 2009-2021 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -25,49 +25,18 @@ _repr (PyObject *self)
 {
   char buf[80];
   sprintf (buf, "<" PY_MODULE "." PY_CSNAME " instance at %p>", self);
-  return PyString_FromString (buf);
+  return PyUnicode_FromString (buf);
 }
 
 static PyTypeObject PyHeaderType = {
-  PyObject_HEAD_INIT(NULL)
-  0,                         /* ob_size */
-  PY_MODULE "." PY_CSNAME,   /* tp_name */
-  sizeof (PyHeader),         /* tp_basicsize */
-  0,                         /* tp_itemsize */
-  (destructor)_py_dealloc,   /* tp_dealloc */
-  0,                         /* tp_print */
-  0,                         /* tp_getattr; __getattr__ */
-  0,                         /* tp_setattr; __setattr__ */
-  0,                         /* tp_compare; __cmp__ */
-  _repr,                     /* tp_repr; __repr__ */
-  0,                         /* tp_as_number */
-  0,                         /* tp_as_sequence */
-  0,                         /* tp_as_mapping */
-  0,                         /* tp_hash; __hash__ */
-  0,                         /* tp_call; __call__ */
-  _repr,                     /* tp_str; __str__ */
-  0,                         /* tp_getattro */
-  0,                         /* tp_setattro */
-  0,                         /* tp_as_buffer */
-  Py_TPFLAGS_DEFAULT,        /* tp_flags */
-  "",                        /* tp_doc */
-  0,                         /* tp_traverse */
-  0,                         /* tp_clear */
-  0,                         /* tp_richcompare */
-  0,                         /* tp_weaklistoffset */
-  0,                         /* tp_iter */
-  0,                         /* tp_iternext */
-  0,                         /* tp_methods */
-  0,                         /* tp_members */
-  0,                         /* tp_getset */
-  0,                         /* tp_base */
-  0,                         /* tp_dict */
-  0,                         /* tp_descr_get */
-  0,                         /* tp_descr_set */
-  0,                         /* tp_dictoffset */
-  0,                         /* tp_init */
-  0,                         /* tp_alloc */
-  0,                         /* tp_new */
+  .ob_base = { PyObject_HEAD_INIT(NULL) },
+  .tp_name = PY_MODULE "." PY_CSNAME,
+  .tp_basicsize = sizeof (PyHeader),
+  .tp_dealloc = (destructor)_py_dealloc,
+  .tp_repr = _repr,
+  .tp_str = _repr,
+  .tp_flags = Py_TPFLAGS_DEFAULT,
+  .tp_doc = "",
 };
 
 PyHeader *
@@ -87,7 +56,7 @@ api_header_size (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_header_size (py_hdr->hdr, &size);
-  return status_object (status, PyInt_FromSize_t (size));
+  return status_object (status, PyLong_FromSize_t (size));
 }
 
 static PyObject *
@@ -101,7 +70,7 @@ api_header_lines (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_header_lines (py_hdr->hdr, &lines);
-  return status_object (status, PyInt_FromSize_t (lines));
+  return status_object (status, PyLong_FromSize_t (lines));
 }
 
 static PyObject *
@@ -116,7 +85,7 @@ api_header_get_value (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_header_sget_value (py_hdr->hdr, name, &value);
-  return status_object (status, PyString_FromString (mu_prstr (value)));
+  return status_object (status, PyUnicode_FromString (mu_prstr (value)));
 }
 
 static PyObject *
@@ -132,7 +101,7 @@ api_header_get_value_n (PyObject *self, PyObject *args)
     return NULL;
   ASSERT_INDEX_RANGE (n, "header");
   status = mu_header_sget_value_n (py_hdr->hdr, name, n, &value);
-  return status_object (status, PyString_FromString (mu_prstr (value)));
+  return status_object (status, PyUnicode_FromString (mu_prstr (value)));
 }
 
 static PyObject *
@@ -147,7 +116,7 @@ api_header_set_value (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_header_set_value (py_hdr->hdr, name, value, replace);
-  return _ro (PyInt_FromLong (status));
+  return _ro (PyLong_FromLong (status));
 }
 
 static PyObject *
@@ -161,7 +130,7 @@ api_header_get_field_count (PyObject *self, PyObject *args)
     return NULL;
 
   status = mu_header_get_field_count (py_hdr->hdr, &count);
-  return status_object (status, PyInt_FromSize_t (count));
+  return status_object (status, PyLong_FromSize_t (count));
 }
 
 static PyObject *
@@ -176,7 +145,7 @@ api_header_get_field_name (PyObject *self, PyObject *args)
     return NULL;
   ASSERT_INDEX_RANGE (idx, "header");
   status = mu_header_sget_field_name (py_hdr->hdr, idx, &name);
-  return status_object (status, PyString_FromString (mu_prstr (name)));
+  return status_object (status, PyUnicode_FromString (mu_prstr (name)));
 }
 
 static PyObject *
@@ -191,7 +160,7 @@ api_header_get_field_value (PyObject *self, PyObject *args)
     return NULL;
   ASSERT_INDEX_RANGE (idx, "header");
   status = mu_header_sget_field_value (py_hdr->hdr, idx, &value);
-  return status_object (status, PyString_FromString (mu_prstr (value)));
+  return status_object (status, PyUnicode_FromString (mu_prstr (value)));
 }
 
 static PyMethodDef methods[] = {
@@ -222,6 +191,14 @@ static PyMethodDef methods[] = {
   { NULL, NULL, 0, NULL }
 };
 
+static struct PyModuleDef moduledef = {
+  PyModuleDef_HEAD_INIT,
+  PY_MODULE,
+  NULL,
+  -1,
+  methods
+};
+
 int
 mu_py_init_header (void)
 {
@@ -233,7 +210,7 @@ void
 _mu_py_attach_header (void)
 {
   PyObject *m;
-  if ((m = _mu_py_attach_module (PY_MODULE, methods)))
+  if ((m = _mu_py_attach_module (&moduledef)))
     {
       Py_INCREF (&PyHeaderType);
       PyModule_AddObject (m, PY_CSNAME, (PyObject *)&PyHeaderType);
